<script>
  (function() {
    var cx = '{{site.google_search}}';
    var gcse = document.createElement('script');
    gcse.type = 'text/javascript';
    gcse.async = true;
    gcse.src = 'https://cse.google.com/cse.js?cx=' + cx;
    var s = document.getElementsByTagName('script')[0];
    s.parentNode.insertBefore(gcse, s);
  })();
</script>

<div id="gcs-search-container">
    <gcse:search></gcse:search>
</div>

