# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {}  # type: ignore

modules = []  # type: ignore

git_url = "https://github.com/shunkakinoki/notebook/tree/master/"


def custom_doc_links(name):
    return None
